================
acdh-tei-pyutils
================

.. image:: https://github.com/acdh-oeaw/acdh-tei-pyutils/workflows/Build/badge.svg
        :target: https://github.com/acdh-oeaw/acdh-tei-pyutils/workflows/Build/badge.svg
        :alt: Github Workflow Build ACDH XML PyUtils Status

.. image:: https://github.com/acdh-oeaw/acdh-tei-pyutils/workflows/Test/badge.svg
        :target: https://github.com/acdh-oeaw/acdh-tei-pyutils/workflows/Test/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/acdh-tei-pyutils.svg
        :target: https://pypi.python.org/pypi/acdh-tei-pyutils
        :alt: PyPI Status

.. image:: https://readthedocs.org/projects/acdh-tei-pyutils/badge/?version=latest
        :target: https://acdh-tei-pyutils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
 
 
.. image:: https://codecov.io/gh/acdh-oeaw/acdh-tei-pyutils/branch/master/graph/badge.svg?token=y6HUg72XnH
      :target: https://codecov.io/gh/acdh-oeaw/acdh-tei-pyutils
    


Utilty functions to work with TEI Documents


* Free software: MIT
* Documentation: https://acdh-tei-pyutils.readthedocs.io.


Credits
-------

This package was created with cookietemple_ using Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter